Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p1beta1FaceAnnotationLandmark

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb

Overview

A face-specific landmark (for example, a face feature). Landmark positions may fall outside the bounds of the image if the face is near one or more edges of the image. Therefore it is NOT guaranteed that 0 <= x < width or 0 <= y < height.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p1beta1FaceAnnotationLandmark

Returns a new instance of GoogleCloudVisionV1p1beta1FaceAnnotationLandmark.



1501
1502
1503
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 1501

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#positionGoogle::Apis::VisionV1p2beta1::GoogleCloudVisionV1p1beta1Position

A 3D position in the image, used primarily for Face detection landmarks. A valid Position must have both x and y coordinates. The position coordinates are in the same scale as the original image. Corresponds to the JSON property position



1494
1495
1496
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 1494

def position
  @position
end

#typeString

Face landmark type. Corresponds to the JSON property type

Returns:

  • (String)


1499
1500
1501
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 1499

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1506
1507
1508
1509
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 1506

def update!(**args)
  @position = args[:position] if args.key?(:position)
  @type = args[:type] if args.key?(:type)
end