Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p1beta1LocationInfo
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p1beta1LocationInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb
Overview
Detected entity location information.
Instance Attribute Summary collapse
-
#lat_lng ⇒ Google::Apis::VisionV1p2beta1::LatLng
An object that represents a latitude/longitude pair.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVisionV1p1beta1LocationInfo
constructor
A new instance of GoogleCloudVisionV1p1beta1LocationInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVisionV1p1beta1LocationInfo
Returns a new instance of GoogleCloudVisionV1p1beta1LocationInfo.
1703 1704 1705 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 1703 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lat_lng ⇒ Google::Apis::VisionV1p2beta1::LatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property latLng
1701 1702 1703 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 1701 def lat_lng @lat_lng end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1708 1709 1710 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 1708 def update!(**args) @lat_lng = args[:lat_lng] if args.key?(:lat_lng) end |