Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p1beta1Product
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p1beta1Product
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb
Overview
A Product contains ReferenceImages.
Instance Attribute Summary collapse
-
#description ⇒ String
User-provided metadata to be stored with this product.
-
#display_name ⇒ String
The user-provided name for this Product.
-
#name ⇒ String
The resource name of the product.
-
#product_category ⇒ String
Immutable.
-
#product_labels ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p1beta1ProductKeyValue>
Key-value pairs that can be attached to a product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVisionV1p1beta1Product
constructor
A new instance of GoogleCloudVisionV1p1beta1Product.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVisionV1p1beta1Product
Returns a new instance of GoogleCloudVisionV1p1beta1Product.
1958 1959 1960 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 1958 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
User-provided metadata to be stored with this product. Must be at most 4096
characters long.
Corresponds to the JSON property description
1924 1925 1926 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 1924 def description @description end |
#display_name ⇒ String
The user-provided name for this Product. Must not be empty. Must be at most
4096 characters long.
Corresponds to the JSON property displayName
1930 1931 1932 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 1930 def display_name @display_name end |
#name ⇒ String
The resource name of the product. Format is: projects/PROJECT_ID/locations/
LOC_ID/products/PRODUCT_ID. This field is ignored when creating a product.
Corresponds to the JSON property name
1936 1937 1938 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 1936 def name @name end |
#product_category ⇒ String
Immutable. The category for the product identified by the reference image.
This should be one of "homegoods-v2", "apparel-v2", "toys-v2", "packagedgoods-
v1" or "general-v1". The legacy categories "homegoods", "apparel", and "toys"
are still supported, but these should not be used for new products.
Corresponds to the JSON property productCategory
1944 1945 1946 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 1944 def product_category @product_category end |
#product_labels ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p1beta1ProductKeyValue>
Key-value pairs that can be attached to a product. At query time, constraints
can be specified based on the product_labels. Note that integer values can be
provided as strings, e.g. "1199". Only strings with integer values can match a
range-based restriction which is to be supported soon. Multiple values can be
assigned to the same key. One product may have up to 500 product_labels.
Notice that the total number of distinct product_labels over all products in
one ProductSet cannot exceed 1M, otherwise the product search pipeline will
refuse to work for that ProductSet.
Corresponds to the JSON property productLabels
1956 1957 1958 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 1956 def product_labels @product_labels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1963 1964 1965 1966 1967 1968 1969 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 1963 def update!(**args) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @product_category = args[:product_category] if args.key?(:product_category) @product_labels = args[:product_labels] if args.key?(:product_labels) end |