Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p1beta1WebDetectionWebPage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb

Overview

Metadata for web pages.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p1beta1WebDetectionWebPage

Returns a new instance of GoogleCloudVisionV1p1beta1WebDetectionWebPage.



2558
2559
2560
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2558

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#full_matching_imagesArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p1beta1WebDetectionWebImage>

Fully matching images on the page. Can include resized copies of the query image. Corresponds to the JSON property fullMatchingImages



2534
2535
2536
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2534

def full_matching_images
  @full_matching_images
end

#page_titleString

Title for the web page, may contain HTML markups. Corresponds to the JSON property pageTitle

Returns:

  • (String)


2539
2540
2541
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2539

def page_title
  @page_title
end

#partial_matching_imagesArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p1beta1WebDetectionWebImage>

Partial matching images on the page. Those images are similar enough to share some key-point features. For example an original image will likely have partial matching for its crops. Corresponds to the JSON property partialMatchingImages



2546
2547
2548
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2546

def partial_matching_images
  @partial_matching_images
end

#scoreFloat

(Deprecated) Overall relevancy score for the web page. Corresponds to the JSON property score

Returns:

  • (Float)


2551
2552
2553
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2551

def score
  @score
end

#urlString

The result web page URL. Corresponds to the JSON property url

Returns:

  • (String)


2556
2557
2558
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2556

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2563
2564
2565
2566
2567
2568
2569
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2563

def update!(**args)
  @full_matching_images = args[:full_matching_images] if args.key?(:full_matching_images)
  @page_title = args[:page_title] if args.key?(:page_title)
  @partial_matching_images = args[:partial_matching_images] if args.key?(:partial_matching_images)
  @score = args[:score] if args.key?(:score)
  @url = args[:url] if args.key?(:url)
end