Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1AnnotateImageResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb

Overview

Response to an image annotation request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1AnnotateImageResponse

Returns a new instance of GoogleCloudVisionV1p2beta1AnnotateImageResponse.



2816
2817
2818
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2816

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contextGoogle::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1ImageAnnotationContext

If an image was produced from a file (e.g. a PDF), this message gives information about the source of that image. Corresponds to the JSON property context



2737
2738
2739
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2737

def context
  @context
end

#crop_hints_annotationGoogle::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1CropHintsAnnotation

Set of crop hints that are used to generate new crops when serving images. Corresponds to the JSON property cropHintsAnnotation



2742
2743
2744
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2742

def crop_hints_annotation
  @crop_hints_annotation
end

#errorGoogle::Apis::VisionV1p2beta1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



2752
2753
2754
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2752

def error
  @error
end

#face_annotationsArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1FaceAnnotation>

If present, face detection has completed successfully. Corresponds to the JSON property faceAnnotations



2757
2758
2759
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2757

def face_annotations
  @face_annotations
end

#full_text_annotationGoogle::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1TextAnnotation

TextAnnotation contains a structured representation of OCR extracted text. The hierarchy of an OCR extracted text structure is like this: TextAnnotation -> Page -> Block -> Paragraph -> Word -> Symbol Each structural component, starting from Page, may further have their own properties. Properties describe detected languages, breaks etc.. Please refer to the TextAnnotation. TextProperty message definition below for more detail. Corresponds to the JSON property fullTextAnnotation



2767
2768
2769
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2767

def full_text_annotation
  @full_text_annotation
end

#image_properties_annotationGoogle::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1ImageProperties

Stores image properties, such as dominant colors. Corresponds to the JSON property imagePropertiesAnnotation



2772
2773
2774
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2772

def image_properties_annotation
  @image_properties_annotation
end

#label_annotationsArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1EntityAnnotation>

If present, label detection has completed successfully. Corresponds to the JSON property labelAnnotations



2777
2778
2779
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2777

def label_annotations
  @label_annotations
end

#landmark_annotationsArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1EntityAnnotation>

If present, landmark detection has completed successfully. Corresponds to the JSON property landmarkAnnotations



2782
2783
2784
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2782

def landmark_annotations
  @landmark_annotations
end

#localized_object_annotationsArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1LocalizedObjectAnnotation>

If present, localized object detection has completed successfully. This will be sorted descending by confidence score. Corresponds to the JSON property localizedObjectAnnotations



2788
2789
2790
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2788

def localized_object_annotations
  @localized_object_annotations
end

#logo_annotationsArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1EntityAnnotation>

If present, logo detection has completed successfully. Corresponds to the JSON property logoAnnotations



2793
2794
2795
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2793

def logo_annotations
  @logo_annotations
end

#product_search_resultsGoogle::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1ProductSearchResults

Results for a product search request. Corresponds to the JSON property productSearchResults



2798
2799
2800
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2798

def product_search_results
  @product_search_results
end

#safe_search_annotationGoogle::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1SafeSearchAnnotation

Set of features pertaining to the image, computed by computer vision methods over safe-search verticals (for example, adult, spoof, medical, violence). Corresponds to the JSON property safeSearchAnnotation



2804
2805
2806
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2804

def safe_search_annotation
  @safe_search_annotation
end

#text_annotationsArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1EntityAnnotation>

If present, text (OCR) detection has completed successfully. Corresponds to the JSON property textAnnotations



2809
2810
2811
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2809

def text_annotations
  @text_annotations
end

#web_detectionGoogle::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1WebDetection

Relevant information for the image from the Internet. Corresponds to the JSON property webDetection



2814
2815
2816
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2814

def web_detection
  @web_detection
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2821

def update!(**args)
  @context = args[:context] if args.key?(:context)
  @crop_hints_annotation = args[:crop_hints_annotation] if args.key?(:crop_hints_annotation)
  @error = args[:error] if args.key?(:error)
  @face_annotations = args[:face_annotations] if args.key?(:face_annotations)
  @full_text_annotation = args[:full_text_annotation] if args.key?(:full_text_annotation)
  @image_properties_annotation = args[:image_properties_annotation] if args.key?(:image_properties_annotation)
  @label_annotations = args[:label_annotations] if args.key?(:label_annotations)
  @landmark_annotations = args[:landmark_annotations] if args.key?(:landmark_annotations)
  @localized_object_annotations = args[:localized_object_annotations] if args.key?(:localized_object_annotations)
  @logo_annotations = args[:logo_annotations] if args.key?(:logo_annotations)
  @product_search_results = args[:product_search_results] if args.key?(:product_search_results)
  @safe_search_annotation = args[:safe_search_annotation] if args.key?(:safe_search_annotation)
  @text_annotations = args[:text_annotations] if args.key?(:text_annotations)
  @web_detection = args[:web_detection] if args.key?(:web_detection)
end