Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1AsyncBatchAnnotateFilesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb

Overview

Multiple async file annotation requests are batched into a single service call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1AsyncBatchAnnotateFilesRequest

Returns a new instance of GoogleCloudVisionV1p2beta1AsyncBatchAnnotateFilesRequest.



2922
2923
2924
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2922

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsHash<String,String>

Optional. The labels with user-defined metadata for the request. Label keys and values can be no longer than 63 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2906
2907
2908
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2906

def labels
  @labels
end

#parentString

Optional. Target project and location to make a call. Format: projects/ project-id/locations/location-id`. If no parent is specified, a region will be chosen automatically. Supported location-ids:us: USA country only,asia : East asia areas, like Japan, Taiwan,eu: The European Union. Example: projects/project-A/locations/eu. Corresponds to the JSON propertyparent`

Returns:

  • (String)


2915
2916
2917
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2915

def parent
  @parent
end

#requestsArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1AsyncAnnotateFileRequest>

Required. Individual async file annotation requests for this batch. Corresponds to the JSON property requests



2920
2921
2922
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2920

def requests
  @requests
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2927
2928
2929
2930
2931
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2927

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
  @parent = args[:parent] if args.key?(:parent)
  @requests = args[:requests] if args.key?(:requests)
end