Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1AsyncBatchAnnotateImagesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb

Overview

Request for async image annotation for a list of images.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1AsyncBatchAnnotateImagesRequest

Returns a new instance of GoogleCloudVisionV1p2beta1AsyncBatchAnnotateImagesRequest.



2986
2987
2988
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2986

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsHash<String,String>

Optional. The labels with user-defined metadata for the request. Label keys and values can be no longer than 63 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2965
2966
2967
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2965

def labels
  @labels
end

#output_configGoogle::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1OutputConfig

The desired output location and metadata. Corresponds to the JSON property outputConfig



2970
2971
2972
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2970

def output_config
  @output_config
end

#parentString

Optional. Target project and location to make a call. Format: projects/ project-id/locations/location-id`. If no parent is specified, a region will be chosen automatically. Supported location-ids:us: USA country only,asia : East asia areas, like Japan, Taiwan,eu: The European Union. Example: projects/project-A/locations/eu. Corresponds to the JSON propertyparent`

Returns:

  • (String)


2979
2980
2981
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2979

def parent
  @parent
end

#requestsArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1AnnotateImageRequest>

Required. Individual image annotation requests for this batch. Corresponds to the JSON property requests



2984
2985
2986
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2984

def requests
  @requests
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2991
2992
2993
2994
2995
2996
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2991

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
  @output_config = args[:output_config] if args.key?(:output_config)
  @parent = args[:parent] if args.key?(:parent)
  @requests = args[:requests] if args.key?(:requests)
end