Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1BatchAnnotateFilesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb

Overview

A list of requests to annotate files using the BatchAnnotateFiles API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1BatchAnnotateFilesRequest

Returns a new instance of GoogleCloudVisionV1p2beta1BatchAnnotateFilesRequest.



3027
3028
3029
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3027

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsHash<String,String>

Optional. The labels with user-defined metadata for the request. Label keys and values can be no longer than 63 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3010
3011
3012
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3010

def labels
  @labels
end

#parentString

Optional. Target project and location to make a call. Format: projects/ project-id/locations/location-id`. If no parent is specified, a region will be chosen automatically. Supported location-ids:us: USA country only,asia : East asia areas, like Japan, Taiwan,eu: The European Union. Example: projects/project-A/locations/eu. Corresponds to the JSON propertyparent`

Returns:

  • (String)


3019
3020
3021
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3019

def parent
  @parent
end

#requestsArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1AnnotateFileRequest>

Required. The list of file annotation requests. Right now we support only one AnnotateFileRequest in BatchAnnotateFilesRequest. Corresponds to the JSON property requests



3025
3026
3027
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3025

def requests
  @requests
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3032
3033
3034
3035
3036
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3032

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
  @parent = args[:parent] if args.key?(:parent)
  @requests = args[:requests] if args.key?(:requests)
end