Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1BatchAnnotateImagesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb

Overview

Multiple image annotation requests are batched into a single service call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1BatchAnnotateImagesRequest

Returns a new instance of GoogleCloudVisionV1p2beta1BatchAnnotateImagesRequest.



3086
3087
3088
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3086

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsHash<String,String>

Optional. The labels with user-defined metadata for the request. Label keys and values can be no longer than 63 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3070
3071
3072
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3070

def labels
  @labels
end

#parentString

Optional. Target project and location to make a call. Format: projects/ project-id/locations/location-id`. If no parent is specified, a region will be chosen automatically. Supported location-ids:us: USA country only,asia : East asia areas, like Japan, Taiwan,eu: The European Union. Example: projects/project-A/locations/eu. Corresponds to the JSON propertyparent`

Returns:

  • (String)


3079
3080
3081
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3079

def parent
  @parent
end

#requestsArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1AnnotateImageRequest>

Required. Individual image annotation requests for this batch. Corresponds to the JSON property requests



3084
3085
3086
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3084

def requests
  @requests
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3091
3092
3093
3094
3095
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3091

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
  @parent = args[:parent] if args.key?(:parent)
  @requests = args[:requests] if args.key?(:requests)
end