Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1BatchAnnotateImagesResponse
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1BatchAnnotateImagesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb
Overview
Response to a batch image annotation request.
Instance Attribute Summary collapse
-
#responses ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1AnnotateImageResponse>
Individual responses to image annotation requests within the batch.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1BatchAnnotateImagesResponse
constructor
A new instance of GoogleCloudVisionV1p2beta1BatchAnnotateImagesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1BatchAnnotateImagesResponse
Returns a new instance of GoogleCloudVisionV1p2beta1BatchAnnotateImagesResponse.
3107 3108 3109 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3107 def initialize(**args) update!(**args) end |
Instance Attribute Details
#responses ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1AnnotateImageResponse>
Individual responses to image annotation requests within the batch.
Corresponds to the JSON property responses
3105 3106 3107 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3105 def responses @responses end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3112 3113 3114 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3112 def update!(**args) @responses = args[:responses] if args.key?(:responses) end |