Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1EntityAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1EntityAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb
Overview
Set of detected entity features.
Instance Attribute Summary collapse
-
#bounding_poly ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1BoundingPoly
A bounding polygon for the detected image annotation.
-
#confidence ⇒ Float
**Deprecated.
-
#description ⇒ String
Entity textual description, expressed in its
localelanguage. -
#locale ⇒ String
The language code for the locale in which the entity textual
descriptionis expressed. -
#locations ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1LocationInfo>
The location information for the detected entity.
-
#mid ⇒ String
Opaque entity ID.
-
#properties ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1Property>
Some entities may have optional user-supplied
Property(name/value) fields, such a score or string that qualifies the entity. -
#score ⇒ Float
Overall score of the result.
-
#topicality ⇒ Float
The relevancy of the ICA (Image Content Annotation) label to the image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1EntityAnnotation
constructor
A new instance of GoogleCloudVisionV1p2beta1EntityAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1EntityAnnotation
Returns a new instance of GoogleCloudVisionV1p2beta1EntityAnnotation.
3417 3418 3419 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3417 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bounding_poly ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1BoundingPoly
A bounding polygon for the detected image annotation.
Corresponds to the JSON property boundingPoly
3361 3362 3363 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3361 def bounding_poly @bounding_poly end |
#confidence ⇒ Float
Deprecated. Use score instead. The accuracy of the entity detection in
an image. For example, for an image in which the "Eiffel Tower" entity is
detected, this field represents the confidence that there is a tower in the
query image. Range [0, 1].
Corresponds to the JSON property confidence
3369 3370 3371 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3369 def confidence @confidence end |
#description ⇒ String
Entity textual description, expressed in its locale language.
Corresponds to the JSON property description
3374 3375 3376 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3374 def description @description end |
#locale ⇒ String
The language code for the locale in which the entity textual description is
expressed.
Corresponds to the JSON property locale
3380 3381 3382 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3380 def locale @locale end |
#locations ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1LocationInfo>
The location information for the detected entity. Multiple LocationInfo
elements can be present because one location may indicate the location of the
scene in the image, and another location may indicate the location of the
place where the image was taken. Location information is usually present for
landmarks.
Corresponds to the JSON property locations
3389 3390 3391 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3389 def locations @locations end |
#mid ⇒ String
Opaque entity ID. Some IDs may be available in Google Knowledge Graph Search
API.
Corresponds to the JSON property mid
3395 3396 3397 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3395 def mid @mid end |
#properties ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1Property>
Some entities may have optional user-supplied Property (name/value) fields,
such a score or string that qualifies the entity.
Corresponds to the JSON property properties
3401 3402 3403 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3401 def properties @properties end |
#score ⇒ Float
Overall score of the result. Range [0, 1].
Corresponds to the JSON property score
3406 3407 3408 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3406 def score @score end |
#topicality ⇒ Float
The relevancy of the ICA (Image Content Annotation) label to the image. For
example, the relevancy of "tower" is likely higher to an image containing the
detected "Eiffel Tower" than to an image containing a detected distant
towering building, even though the confidence that there is a tower in each
image may be the same. Range [0, 1].
Corresponds to the JSON property topicality
3415 3416 3417 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3415 def topicality @topicality end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3422 3423 3424 3425 3426 3427 3428 3429 3430 3431 3432 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3422 def update!(**args) @bounding_poly = args[:bounding_poly] if args.key?(:bounding_poly) @confidence = args[:confidence] if args.key?(:confidence) @description = args[:description] if args.key?(:description) @locale = args[:locale] if args.key?(:locale) @locations = args[:locations] if args.key?(:locations) @mid = args[:mid] if args.key?(:mid) @properties = args[:properties] if args.key?(:properties) @score = args[:score] if args.key?(:score) @topicality = args[:topicality] if args.key?(:topicality) end |