Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1FaceAnnotationLandmark

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb

Overview

A face-specific landmark (for example, a face feature). Landmark positions may fall outside the bounds of the image if the face is near one or more edges of the image. Therefore it is NOT guaranteed that 0 <= x < width or 0 <= y < height.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1FaceAnnotationLandmark

Returns a new instance of GoogleCloudVisionV1p2beta1FaceAnnotationLandmark.



3562
3563
3564
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3562

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#positionGoogle::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1Position

A 3D position in the image, used primarily for Face detection landmarks. A valid Position must have both x and y coordinates. The position coordinates are in the same scale as the original image. Corresponds to the JSON property position



3555
3556
3557
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3555

def position
  @position
end

#typeString

Face landmark type. Corresponds to the JSON property type

Returns:

  • (String)


3560
3561
3562
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3560

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3567
3568
3569
3570
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3567

def update!(**args)
  @position = args[:position] if args.key?(:position)
  @type = args[:type] if args.key?(:type)
end