Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1Feature

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb

Overview

The type of Google Cloud Vision API detection to perform, and the maximum number of results to return for that type. Multiple Feature objects can be specified in the features list.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1Feature

Returns a new instance of GoogleCloudVisionV1p2beta1Feature.



3597
3598
3599
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3597

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_resultsFixnum

Maximum number of results of this type. Does not apply to TEXT_DETECTION, DOCUMENT_TEXT_DETECTION, or CROP_HINTS. Corresponds to the JSON property maxResults

Returns:

  • (Fixnum)


3583
3584
3585
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3583

def max_results
  @max_results
end

#modelString

Model to use for the feature. Supported values: "builtin/stable" (the default if unset) and "builtin/latest". DOCUMENT_TEXT_DETECTION and TEXT_DETECTION also support "builtin/rc" for the latest release candidate. Corresponds to the JSON property model

Returns:

  • (String)


3590
3591
3592
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3590

def model
  @model
end

#typeString

The feature type. Corresponds to the JSON property type

Returns:

  • (String)


3595
3596
3597
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3595

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3602
3603
3604
3605
3606
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3602

def update!(**args)
  @max_results = args[:max_results] if args.key?(:max_results)
  @model = args[:model] if args.key?(:model)
  @type = args[:type] if args.key?(:type)
end