Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1Position
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1Position
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb
Overview
A 3D position in the image, used primarily for Face detection landmarks. A valid Position must have both x and y coordinates. The position coordinates are in the same scale as the original image.
Instance Attribute Summary collapse
-
#x ⇒ Float
X coordinate.
-
#y ⇒ Float
Y coordinate.
-
#z ⇒ Float
Z coordinate (or depth).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1Position
constructor
A new instance of GoogleCloudVisionV1p2beta1Position.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1Position
Returns a new instance of GoogleCloudVisionV1p2beta1Position.
4156 4157 4158 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 4156 def initialize(**args) update!(**args) end |
Instance Attribute Details
#x ⇒ Float
X coordinate.
Corresponds to the JSON property x
4144 4145 4146 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 4144 def x @x end |
#y ⇒ Float
Y coordinate.
Corresponds to the JSON property y
4149 4150 4151 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 4149 def y @y end |
#z ⇒ Float
Z coordinate (or depth).
Corresponds to the JSON property z
4154 4155 4156 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 4154 def z @z end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4161 4162 4163 4164 4165 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 4161 def update!(**args) @x = args[:x] if args.key?(:x) @y = args[:y] if args.key?(:y) @z = args[:z] if args.key?(:z) end |