Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1ProductSearchResultsResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb

Overview

Information about a product.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1ProductSearchResultsResult

Returns a new instance of GoogleCloudVisionV1p2beta1ProductSearchResultsResult.



4427
4428
4429
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 4427

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#imageString

The resource name of the image from the product that is the closest match to the query. Corresponds to the JSON property image

Returns:

  • (String)


4414
4415
4416
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 4414

def image
  @image
end

#productGoogle::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1Product

A Product contains ReferenceImages. Corresponds to the JSON property product



4419
4420
4421
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 4419

def product
  @product
end

#scoreFloat

A confidence level on the match, ranging from 0 (no confidence) to 1 (full confidence). Corresponds to the JSON property score

Returns:

  • (Float)


4425
4426
4427
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 4425

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4432
4433
4434
4435
4436
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 4432

def update!(**args)
  @image = args[:image] if args.key?(:image)
  @product = args[:product] if args.key?(:product)
  @score = args[:score] if args.key?(:score)
end