Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1AnnotateImageResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb

Overview

Response to an image annotation request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p3beta1AnnotateImageResponse

Returns a new instance of GoogleCloudVisionV1p3beta1AnnotateImageResponse.



5096
5097
5098
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 5096

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contextGoogle::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1ImageAnnotationContext

If an image was produced from a file (e.g. a PDF), this message gives information about the source of that image. Corresponds to the JSON property context



5017
5018
5019
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 5017

def context
  @context
end

#crop_hints_annotationGoogle::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1CropHintsAnnotation

Set of crop hints that are used to generate new crops when serving images. Corresponds to the JSON property cropHintsAnnotation



5022
5023
5024
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 5022

def crop_hints_annotation
  @crop_hints_annotation
end

#errorGoogle::Apis::VisionV1p2beta1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



5032
5033
5034
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 5032

def error
  @error
end

#face_annotationsArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1FaceAnnotation>

If present, face detection has completed successfully. Corresponds to the JSON property faceAnnotations



5037
5038
5039
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 5037

def face_annotations
  @face_annotations
end

#full_text_annotationGoogle::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1TextAnnotation

TextAnnotation contains a structured representation of OCR extracted text. The hierarchy of an OCR extracted text structure is like this: TextAnnotation -> Page -> Block -> Paragraph -> Word -> Symbol Each structural component, starting from Page, may further have their own properties. Properties describe detected languages, breaks etc.. Please refer to the TextAnnotation. TextProperty message definition below for more detail. Corresponds to the JSON property fullTextAnnotation



5047
5048
5049
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 5047

def full_text_annotation
  @full_text_annotation
end

#image_properties_annotationGoogle::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1ImageProperties

Stores image properties, such as dominant colors. Corresponds to the JSON property imagePropertiesAnnotation



5052
5053
5054
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 5052

def image_properties_annotation
  @image_properties_annotation
end

#label_annotationsArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1EntityAnnotation>

If present, label detection has completed successfully. Corresponds to the JSON property labelAnnotations



5057
5058
5059
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 5057

def label_annotations
  @label_annotations
end

#landmark_annotationsArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1EntityAnnotation>

If present, landmark detection has completed successfully. Corresponds to the JSON property landmarkAnnotations



5062
5063
5064
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 5062

def landmark_annotations
  @landmark_annotations
end

#localized_object_annotationsArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1LocalizedObjectAnnotation>

If present, localized object detection has completed successfully. This will be sorted descending by confidence score. Corresponds to the JSON property localizedObjectAnnotations



5068
5069
5070
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 5068

def localized_object_annotations
  @localized_object_annotations
end

#logo_annotationsArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1EntityAnnotation>

If present, logo detection has completed successfully. Corresponds to the JSON property logoAnnotations



5073
5074
5075
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 5073

def logo_annotations
  @logo_annotations
end

#product_search_resultsGoogle::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1ProductSearchResults

Results for a product search request. Corresponds to the JSON property productSearchResults



5078
5079
5080
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 5078

def product_search_results
  @product_search_results
end

#safe_search_annotationGoogle::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1SafeSearchAnnotation

Set of features pertaining to the image, computed by computer vision methods over safe-search verticals (for example, adult, spoof, medical, violence). Corresponds to the JSON property safeSearchAnnotation



5084
5085
5086
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 5084

def safe_search_annotation
  @safe_search_annotation
end

#text_annotationsArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1EntityAnnotation>

If present, text (OCR) detection has completed successfully. Corresponds to the JSON property textAnnotations



5089
5090
5091
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 5089

def text_annotations
  @text_annotations
end

#web_detectionGoogle::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1WebDetection

Relevant information for the image from the Internet. Corresponds to the JSON property webDetection



5094
5095
5096
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 5094

def web_detection
  @web_detection
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5101
5102
5103
5104
5105
5106
5107
5108
5109
5110
5111
5112
5113
5114
5115
5116
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 5101

def update!(**args)
  @context = args[:context] if args.key?(:context)
  @crop_hints_annotation = args[:crop_hints_annotation] if args.key?(:crop_hints_annotation)
  @error = args[:error] if args.key?(:error)
  @face_annotations = args[:face_annotations] if args.key?(:face_annotations)
  @full_text_annotation = args[:full_text_annotation] if args.key?(:full_text_annotation)
  @image_properties_annotation = args[:image_properties_annotation] if args.key?(:image_properties_annotation)
  @label_annotations = args[:label_annotations] if args.key?(:label_annotations)
  @landmark_annotations = args[:landmark_annotations] if args.key?(:landmark_annotations)
  @localized_object_annotations = args[:localized_object_annotations] if args.key?(:localized_object_annotations)
  @logo_annotations = args[:logo_annotations] if args.key?(:logo_annotations)
  @product_search_results = args[:product_search_results] if args.key?(:product_search_results)
  @safe_search_annotation = args[:safe_search_annotation] if args.key?(:safe_search_annotation)
  @text_annotations = args[:text_annotations] if args.key?(:text_annotations)
  @web_detection = args[:web_detection] if args.key?(:web_detection)
end