Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1LocationInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb

Overview

Detected entity location information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p3beta1LocationInfo

Returns a new instance of GoogleCloudVisionV1p3beta1LocationInfo.



5846
5847
5848
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 5846

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#lat_lngGoogle::Apis::VisionV1p2beta1::LatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property latLng



5844
5845
5846
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 5844

def lat_lng
  @lat_lng
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5851
5852
5853
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 5851

def update!(**args)
  @lat_lng = args[:lat_lng] if args.key?(:lat_lng)
end