Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1ProductSearchResults

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb

Overview

Results for a product search request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVisionV1p3beta1ProductSearchResults

Returns a new instance of GoogleCloudVisionV1p3beta1ProductSearchResults.



6166
6167
6168
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6166

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#index_timeString

Timestamp of the index which provided these results. Products added to the product set and products removed from the product set after this time are not reflected in the current results. Corresponds to the JSON property indexTime

Returns:

  • (String)


6151
6152
6153
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6151

def index_time
  @index_time
end

#product_grouped_resultsArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1ProductSearchResultsGroupedResult>

List of results grouped by products detected in the query image. Each entry corresponds to one bounding polygon in the query image, and contains the matching products specific to that region. There may be duplicate product matches in the union of all the per-product results. Corresponds to the JSON property productGroupedResults



6159
6160
6161
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6159

def product_grouped_results
  @product_grouped_results
end

#resultsArray<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1ProductSearchResultsResult>

List of results, one for each product match. Corresponds to the JSON property results



6164
6165
6166
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6164

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6171
6172
6173
6174
6175
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6171

def update!(**args)
  @index_time = args[:index_time] if args.key?(:index_time)
  @product_grouped_results = args[:product_grouped_results] if args.key?(:product_grouped_results)
  @results = args[:results] if args.key?(:results)
end