Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1SafeSearchAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p3beta1SafeSearchAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb
Overview
Set of features pertaining to the image, computed by computer vision methods over safe-search verticals (for example, adult, spoof, medical, violence).
Instance Attribute Summary collapse
-
#adult ⇒ String
Represents the adult content likelihood for the image.
-
#medical ⇒ String
Likelihood that this is a medical image.
-
#racy ⇒ String
Likelihood that the request image contains racy content.
-
#spoof ⇒ String
Spoof likelihood.
-
#violence ⇒ String
Likelihood that this image contains violent content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVisionV1p3beta1SafeSearchAnnotation
constructor
A new instance of GoogleCloudVisionV1p3beta1SafeSearchAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVisionV1p3beta1SafeSearchAnnotation
Returns a new instance of GoogleCloudVisionV1p3beta1SafeSearchAnnotation.
6388 6389 6390 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6388 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adult ⇒ String
Represents the adult content likelihood for the image. Adult content may
contain elements such as nudity, pornographic images or cartoons, or sexual
activities.
Corresponds to the JSON property adult
6361 6362 6363 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6361 def adult @adult end |
#medical ⇒ String
Likelihood that this is a medical image.
Corresponds to the JSON property medical
6366 6367 6368 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6366 def medical @medical end |
#racy ⇒ String
Likelihood that the request image contains racy content. Racy content may
include (but is not limited to) skimpy or sheer clothing, strategically
covered nudity, lewd or provocative poses, or close-ups of sensitive body
areas.
Corresponds to the JSON property racy
6374 6375 6376 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6374 def racy @racy end |
#spoof ⇒ String
Spoof likelihood. The likelihood that an modification was made to the image's
canonical version to make it appear funny or offensive.
Corresponds to the JSON property spoof
6380 6381 6382 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6380 def spoof @spoof end |
#violence ⇒ String
Likelihood that this image contains violent content. Violent content may
include death, serious harm, or injury to individuals or groups of individuals.
Corresponds to the JSON property violence
6386 6387 6388 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6386 def violence @violence end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6393 6394 6395 6396 6397 6398 6399 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6393 def update!(**args) @adult = args[:adult] if args.key?(:adult) @medical = args[:medical] if args.key?(:medical) @racy = args[:racy] if args.key?(:racy) @spoof = args[:spoof] if args.key?(:spoof) @violence = args[:violence] if args.key?(:violence) end |