Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1ProductSearchResultsResult
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1ProductSearchResultsResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb
Overview
Information about a product.
Instance Attribute Summary collapse
-
#image ⇒ String
The resource name of the image from the product that is the closest match to the query.
-
#product ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1Product
A Product contains ReferenceImages.
-
#score ⇒ Float
A confidence level on the match, ranging from 0 (no confidence) to 1 (full confidence).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVisionV1p4beta1ProductSearchResultsResult
constructor
A new instance of GoogleCloudVisionV1p4beta1ProductSearchResultsResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVisionV1p4beta1ProductSearchResultsResult
Returns a new instance of GoogleCloudVisionV1p4beta1ProductSearchResultsResult.
8200 8201 8202 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 8200 def initialize(**args) update!(**args) end |
Instance Attribute Details
#image ⇒ String
The resource name of the image from the product that is the closest match to
the query.
Corresponds to the JSON property image
8187 8188 8189 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 8187 def image @image end |
#product ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1Product
A Product contains ReferenceImages.
Corresponds to the JSON property product
8192 8193 8194 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 8192 def product @product end |
#score ⇒ Float
A confidence level on the match, ranging from 0 (no confidence) to 1 (full
confidence).
Corresponds to the JSON property score
8198 8199 8200 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 8198 def score @score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8205 8206 8207 8208 8209 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 8205 def update!(**args) @image = args[:image] if args.key?(:image) @product = args[:product] if args.key?(:product) @score = args[:score] if args.key?(:score) end |