Class: Google::Apis::VisionV1p2beta1::ImportProductSetsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb

Overview

Response message for the ImportProductSets method. This message is returned by the google.longrunning.Operations.GetOperation method in the returned google.longrunning.Operation.response field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportProductSetsResponse

Returns a new instance of ImportProductSetsResponse.



8821
8822
8823
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 8821

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#reference_imagesArray<Google::Apis::VisionV1p2beta1::ReferenceImage>

The list of reference_images that are imported successfully. Corresponds to the JSON property referenceImages



8811
8812
8813
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 8811

def reference_images
  @reference_images
end

#statusesArray<Google::Apis::VisionV1p2beta1::Status>

The rpc status for each ImportProductSet request, including both successes and errors. The number of statuses here matches the number of lines in the csv file, and statuses[i] stores the success or failure status of processing the i- th line of the csv, starting from line 0. Corresponds to the JSON property statuses



8819
8820
8821
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 8819

def statuses
  @statuses
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8826
8827
8828
8829
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 8826

def update!(**args)
  @reference_images = args[:reference_images] if args.key?(:reference_images)
  @statuses = args[:statuses] if args.key?(:statuses)
end