Class: Google::Apis::VisionV1p2beta1::LocationInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb

Overview

Detected entity location information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LocationInfo

Returns a new instance of LocationInfo.



9010
9011
9012
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9010

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#lat_lngGoogle::Apis::VisionV1p2beta1::LatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property latLng



9008
9009
9010
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9008

def lat_lng
  @lat_lng
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9015
9016
9017
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9015

def update!(**args)
  @lat_lng = args[:lat_lng] if args.key?(:lat_lng)
end