Class: Google::Apis::VisionV1p2beta1::ReferenceImage
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p2beta1::ReferenceImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb
Overview
A ReferenceImage represents a product image and its associated metadata,
such as bounding boxes.
Instance Attribute Summary collapse
-
#bounding_polys ⇒ Array<Google::Apis::VisionV1p2beta1::BoundingPoly>
Optional.
-
#name ⇒ String
The resource name of the reference image.
-
#uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReferenceImage
constructor
A new instance of ReferenceImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReferenceImage
Returns a new instance of ReferenceImage.
9474 9475 9476 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9474 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bounding_polys ⇒ Array<Google::Apis::VisionV1p2beta1::BoundingPoly>
Optional. Bounding polygons around the areas of interest in the reference
image. If this field is empty, the system will try to detect regions of
interest. At most 10 bounding polygons will be used. The provided shape is
converted into a non-rotated rectangle. Once converted, the small edge of the
rectangle must be greater than or equal to 300 pixels. The aspect ratio must
be 1:4 or less (i.e. 1:3 is ok; 1:5 is not).
Corresponds to the JSON property boundingPolys
9459 9460 9461 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9459 def bounding_polys @bounding_polys end |
#name ⇒ String
The resource name of the reference image. Format is: projects/PROJECT_ID/
locations/LOC_ID/products/PRODUCT_ID/referenceImages/IMAGE_ID. This field is
ignored when creating a reference image.
Corresponds to the JSON property name
9466 9467 9468 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9466 def name @name end |
#uri ⇒ String
Required. The Google Cloud Storage URI of the reference image. The URI must
start with gs://.
Corresponds to the JSON property uri
9472 9473 9474 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9472 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9479 9480 9481 9482 9483 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9479 def update!(**args) @bounding_polys = args[:bounding_polys] if args.key?(:bounding_polys) @name = args[:name] if args.key?(:name) @uri = args[:uri] if args.key?(:uri) end |