Class: Google::Apis::VisionV1p2beta1::WebPage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb

Overview

Metadata for web pages.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WebPage

Returns a new instance of WebPage.



9896
9897
9898
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#full_matching_imagesArray<Google::Apis::VisionV1p2beta1::WebImage>

Fully matching images on the page. Can include resized copies of the query image. Corresponds to the JSON property fullMatchingImages



9872
9873
9874
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9872

def full_matching_images
  @full_matching_images
end

#page_titleString

Title for the web page, may contain HTML markups. Corresponds to the JSON property pageTitle

Returns:

  • (String)


9877
9878
9879
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9877

def page_title
  @page_title
end

#partial_matching_imagesArray<Google::Apis::VisionV1p2beta1::WebImage>

Partial matching images on the page. Those images are similar enough to share some key-point features. For example an original image will likely have partial matching for its crops. Corresponds to the JSON property partialMatchingImages



9884
9885
9886
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9884

def partial_matching_images
  @partial_matching_images
end

#scoreFloat

(Deprecated) Overall relevancy score for the web page. Corresponds to the JSON property score

Returns:

  • (Float)


9889
9890
9891
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9889

def score
  @score
end

#urlString

The result web page URL. Corresponds to the JSON property url

Returns:

  • (String)


9894
9895
9896
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9894

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9901
9902
9903
9904
9905
9906
9907
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9901

def update!(**args)
  @full_matching_images = args[:full_matching_images] if args.key?(:full_matching_images)
  @page_title = args[:page_title] if args.key?(:page_title)
  @partial_matching_images = args[:partial_matching_images] if args.key?(:partial_matching_images)
  @score = args[:score] if args.key?(:score)
  @url = args[:url] if args.key?(:url)
end