Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p1beta1SafeSearchAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p1beta1SafeSearchAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb
Overview
Set of features pertaining to the image, computed by computer vision methods over safe-search verticals (for example, adult, spoof, medical, violence).
Instance Attribute Summary collapse
-
#adult ⇒ String
Represents the adult content likelihood for the image.
-
#medical ⇒ String
Likelihood that this is a medical image.
-
#racy ⇒ String
Likelihood that the request image contains racy content.
-
#spoof ⇒ String
Spoof likelihood.
-
#violence ⇒ String
Likelihood that this image contains violent content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVisionV1p1beta1SafeSearchAnnotation
constructor
A new instance of GoogleCloudVisionV1p1beta1SafeSearchAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVisionV1p1beta1SafeSearchAnnotation
Returns a new instance of GoogleCloudVisionV1p1beta1SafeSearchAnnotation.
2205 2206 2207 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2205 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adult ⇒ String
Represents the adult content likelihood for the image. Adult content may
contain elements such as nudity, pornographic images or cartoons, or sexual
activities.
Corresponds to the JSON property adult
2178 2179 2180 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2178 def adult @adult end |
#medical ⇒ String
Likelihood that this is a medical image.
Corresponds to the JSON property medical
2183 2184 2185 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2183 def medical @medical end |
#racy ⇒ String
Likelihood that the request image contains racy content. Racy content may
include (but is not limited to) skimpy or sheer clothing, strategically
covered nudity, lewd or provocative poses, or close-ups of sensitive body
areas.
Corresponds to the JSON property racy
2191 2192 2193 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2191 def racy @racy end |
#spoof ⇒ String
Spoof likelihood. The likelihood that an modification was made to the image's
canonical version to make it appear funny or offensive.
Corresponds to the JSON property spoof
2197 2198 2199 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2197 def spoof @spoof end |
#violence ⇒ String
Likelihood that this image contains violent content. Violent content may
include death, serious harm, or injury to individuals or groups of individuals.
Corresponds to the JSON property violence
2203 2204 2205 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2203 def violence @violence end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2210 2211 2212 2213 2214 2215 2216 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 2210 def update!(**args) @adult = args[:adult] if args.key?(:adult) @medical = args[:medical] if args.key?(:medical) @racy = args[:racy] if args.key?(:racy) @spoof = args[:spoof] if args.key?(:spoof) @violence = args[:violence] if args.key?(:violence) end |