Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1ImageContext
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1ImageContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb
Overview
Image context and/or feature-specific parameters.
Instance Attribute Summary collapse
-
#crop_hints_params ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1CropHintsParams
Parameters for crop hints annotation request.
-
#language_hints ⇒ Array<String>
List of languages to use for TEXT_DETECTION.
-
#lat_long_rect ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1LatLongRect
Rectangle determined by min and max
LatLngpairs. -
#product_search_params ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1ProductSearchParams
Parameters for a product search request.
-
#text_detection_params ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1TextDetectionParams
Parameters for text detections.
-
#web_detection_params ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1WebDetectionParams
Parameters for web detection request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1ImageContext
constructor
A new instance of GoogleCloudVisionV1p2beta1ImageContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1ImageContext
Returns a new instance of GoogleCloudVisionV1p2beta1ImageContext.
3760 3761 3762 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3760 def initialize(**args) update!(**args) end |
Instance Attribute Details
#crop_hints_params ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1CropHintsParams
Parameters for crop hints annotation request.
Corresponds to the JSON property cropHintsParams
3725 3726 3727 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3725 def crop_hints_params @crop_hints_params end |
#language_hints ⇒ Array<String>
List of languages to use for TEXT_DETECTION. In most cases, an empty value
yields the best results since it enables automatic language detection. For
languages based on the Latin alphabet, setting language_hints is not needed.
In rare cases, when the language of the text in the image is known, setting a
hint will help get better results (although it will be a significant hindrance
if the hint is wrong). Text detection returns an error if one or more of the
specified languages is not one of the supported languages.
Corresponds to the JSON property languageHints
3737 3738 3739 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3737 def language_hints @language_hints end |
#lat_long_rect ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1LatLongRect
Rectangle determined by min and max LatLng pairs.
Corresponds to the JSON property latLongRect
3742 3743 3744 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3742 def lat_long_rect @lat_long_rect end |
#product_search_params ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1ProductSearchParams
Parameters for a product search request.
Corresponds to the JSON property productSearchParams
3747 3748 3749 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3747 def product_search_params @product_search_params end |
#text_detection_params ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1TextDetectionParams
Parameters for text detections. This is used to control TEXT_DETECTION and
DOCUMENT_TEXT_DETECTION features.
Corresponds to the JSON property textDetectionParams
3753 3754 3755 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3753 def text_detection_params @text_detection_params end |
#web_detection_params ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1WebDetectionParams
Parameters for web detection request.
Corresponds to the JSON property webDetectionParams
3758 3759 3760 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3758 def web_detection_params @web_detection_params end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3765 3766 3767 3768 3769 3770 3771 3772 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3765 def update!(**args) @crop_hints_params = args[:crop_hints_params] if args.key?(:crop_hints_params) @language_hints = args[:language_hints] if args.key?(:language_hints) @lat_long_rect = args[:lat_long_rect] if args.key?(:lat_long_rect) @product_search_params = args[:product_search_params] if args.key?(:product_search_params) @text_detection_params = args[:text_detection_params] if args.key?(:text_detection_params) @web_detection_params = args[:web_detection_params] if args.key?(:web_detection_params) end |