Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1LatLongRect
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1LatLongRect
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb
Overview
Rectangle determined by min and max LatLng pairs.
Instance Attribute Summary collapse
-
#max_lat_lng ⇒ Google::Apis::VisionV1p2beta1::LatLng
An object that represents a latitude/longitude pair.
-
#min_lat_lng ⇒ Google::Apis::VisionV1p2beta1::LatLng
An object that represents a latitude/longitude pair.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1LatLongRect
constructor
A new instance of GoogleCloudVisionV1p2beta1LatLongRect.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1LatLongRect
Returns a new instance of GoogleCloudVisionV1p2beta1LatLongRect.
3888 3889 3890 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3888 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_lat_lng ⇒ Google::Apis::VisionV1p2beta1::LatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property maxLatLng
3878 3879 3880 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3878 def max_lat_lng @max_lat_lng end |
#min_lat_lng ⇒ Google::Apis::VisionV1p2beta1::LatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property minLatLng
3886 3887 3888 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3886 def min_lat_lng @min_lat_lng end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3893 3894 3895 3896 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 3893 def update!(**args) @max_lat_lng = args[:max_lat_lng] if args.key?(:max_lat_lng) @min_lat_lng = args[:min_lat_lng] if args.key?(:min_lat_lng) end |