Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1SafeSearchAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p2beta1SafeSearchAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb
Overview
Set of features pertaining to the image, computed by computer vision methods over safe-search verticals (for example, adult, spoof, medical, violence).
Instance Attribute Summary collapse
-
#adult ⇒ String
Represents the adult content likelihood for the image.
-
#medical ⇒ String
Likelihood that this is a medical image.
-
#racy ⇒ String
Likelihood that the request image contains racy content.
-
#spoof ⇒ String
Spoof likelihood.
-
#violence ⇒ String
Likelihood that this image contains violent content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1SafeSearchAnnotation
constructor
A new instance of GoogleCloudVisionV1p2beta1SafeSearchAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVisionV1p2beta1SafeSearchAnnotation
Returns a new instance of GoogleCloudVisionV1p2beta1SafeSearchAnnotation.
4507 4508 4509 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 4507 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adult ⇒ String
Represents the adult content likelihood for the image. Adult content may
contain elements such as nudity, pornographic images or cartoons, or sexual
activities.
Corresponds to the JSON property adult
4480 4481 4482 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 4480 def adult @adult end |
#medical ⇒ String
Likelihood that this is a medical image.
Corresponds to the JSON property medical
4485 4486 4487 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 4485 def medical @medical end |
#racy ⇒ String
Likelihood that the request image contains racy content. Racy content may
include (but is not limited to) skimpy or sheer clothing, strategically
covered nudity, lewd or provocative poses, or close-ups of sensitive body
areas.
Corresponds to the JSON property racy
4493 4494 4495 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 4493 def racy @racy end |
#spoof ⇒ String
Spoof likelihood. The likelihood that an modification was made to the image's
canonical version to make it appear funny or offensive.
Corresponds to the JSON property spoof
4499 4500 4501 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 4499 def spoof @spoof end |
#violence ⇒ String
Likelihood that this image contains violent content. Violent content may
include death, serious harm, or injury to individuals or groups of individuals.
Corresponds to the JSON property violence
4505 4506 4507 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 4505 def violence @violence end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4512 4513 4514 4515 4516 4517 4518 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 4512 def update!(**args) @adult = args[:adult] if args.key?(:adult) @medical = args[:medical] if args.key?(:medical) @racy = args[:racy] if args.key?(:racy) @spoof = args[:spoof] if args.key?(:spoof) @violence = args[:violence] if args.key?(:violence) end |