Class: Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1AnnotateImageResponse
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1AnnotateImageResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb
Overview
Response to an image annotation request.
Instance Attribute Summary collapse
-
#context ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1ImageAnnotationContext
If an image was produced from a file (e.g. a PDF), this message gives information about the source of that image.
-
#crop_hints_annotation ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1CropHintsAnnotation
Set of crop hints that are used to generate new crops when serving images.
-
#error ⇒ Google::Apis::VisionV1p2beta1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#face_annotations ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1FaceAnnotation>
If present, face detection has completed successfully.
-
#full_text_annotation ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1TextAnnotation
TextAnnotation contains a structured representation of OCR extracted text.
-
#image_properties_annotation ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1ImageProperties
Stores image properties, such as dominant colors.
-
#label_annotations ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1EntityAnnotation>
If present, label detection has completed successfully.
-
#landmark_annotations ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1EntityAnnotation>
If present, landmark detection has completed successfully.
-
#localized_object_annotations ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1LocalizedObjectAnnotation>
If present, localized object detection has completed successfully.
-
#logo_annotations ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1EntityAnnotation>
If present, logo detection has completed successfully.
-
#product_search_results ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1ProductSearchResults
Results for a product search request.
-
#safe_search_annotation ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1SafeSearchAnnotation
Set of features pertaining to the image, computed by computer vision methods over safe-search verticals (for example, adult, spoof, medical, violence).
-
#text_annotations ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1EntityAnnotation>
If present, text (OCR) detection has completed successfully.
-
#web_detection ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1WebDetection
Relevant information for the image from the Internet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVisionV1p4beta1AnnotateImageResponse
constructor
A new instance of GoogleCloudVisionV1p4beta1AnnotateImageResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVisionV1p4beta1AnnotateImageResponse
Returns a new instance of GoogleCloudVisionV1p4beta1AnnotateImageResponse.
6924 6925 6926 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6924 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1ImageAnnotationContext
If an image was produced from a file (e.g. a PDF), this message gives
information about the source of that image.
Corresponds to the JSON property context
6845 6846 6847 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6845 def context @context end |
#crop_hints_annotation ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1CropHintsAnnotation
Set of crop hints that are used to generate new crops when serving images.
Corresponds to the JSON property cropHintsAnnotation
6850 6851 6852 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6850 def crop_hints_annotation @crop_hints_annotation end |
#error ⇒ Google::Apis::VisionV1p2beta1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
6860 6861 6862 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6860 def error @error end |
#face_annotations ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1FaceAnnotation>
If present, face detection has completed successfully.
Corresponds to the JSON property faceAnnotations
6865 6866 6867 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6865 def face_annotations @face_annotations end |
#full_text_annotation ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1TextAnnotation
TextAnnotation contains a structured representation of OCR extracted text. The
hierarchy of an OCR extracted text structure is like this: TextAnnotation ->
Page -> Block -> Paragraph -> Word -> Symbol Each structural component,
starting from Page, may further have their own properties. Properties describe
detected languages, breaks etc.. Please refer to the TextAnnotation.
TextProperty message definition below for more detail.
Corresponds to the JSON property fullTextAnnotation
6875 6876 6877 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6875 def full_text_annotation @full_text_annotation end |
#image_properties_annotation ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1ImageProperties
Stores image properties, such as dominant colors.
Corresponds to the JSON property imagePropertiesAnnotation
6880 6881 6882 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6880 def image_properties_annotation @image_properties_annotation end |
#label_annotations ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1EntityAnnotation>
If present, label detection has completed successfully.
Corresponds to the JSON property labelAnnotations
6885 6886 6887 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6885 def label_annotations @label_annotations end |
#landmark_annotations ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1EntityAnnotation>
If present, landmark detection has completed successfully.
Corresponds to the JSON property landmarkAnnotations
6890 6891 6892 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6890 def landmark_annotations @landmark_annotations end |
#localized_object_annotations ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1LocalizedObjectAnnotation>
If present, localized object detection has completed successfully. This will
be sorted descending by confidence score.
Corresponds to the JSON property localizedObjectAnnotations
6896 6897 6898 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6896 def localized_object_annotations @localized_object_annotations end |
#logo_annotations ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1EntityAnnotation>
If present, logo detection has completed successfully.
Corresponds to the JSON property logoAnnotations
6901 6902 6903 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6901 def logo_annotations @logo_annotations end |
#product_search_results ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1ProductSearchResults
Results for a product search request.
Corresponds to the JSON property productSearchResults
6906 6907 6908 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6906 def product_search_results @product_search_results end |
#safe_search_annotation ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1SafeSearchAnnotation
Set of features pertaining to the image, computed by computer vision methods
over safe-search verticals (for example, adult, spoof, medical, violence).
Corresponds to the JSON property safeSearchAnnotation
6912 6913 6914 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6912 def safe_search_annotation @safe_search_annotation end |
#text_annotations ⇒ Array<Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1EntityAnnotation>
If present, text (OCR) detection has completed successfully.
Corresponds to the JSON property textAnnotations
6917 6918 6919 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6917 def text_annotations @text_annotations end |
#web_detection ⇒ Google::Apis::VisionV1p2beta1::GoogleCloudVisionV1p4beta1WebDetection
Relevant information for the image from the Internet.
Corresponds to the JSON property webDetection
6922 6923 6924 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6922 def web_detection @web_detection end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 6942 6943 6944 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 6929 def update!(**args) @context = args[:context] if args.key?(:context) @crop_hints_annotation = args[:crop_hints_annotation] if args.key?(:crop_hints_annotation) @error = args[:error] if args.key?(:error) @face_annotations = args[:face_annotations] if args.key?(:face_annotations) @full_text_annotation = args[:full_text_annotation] if args.key?(:full_text_annotation) @image_properties_annotation = args[:image_properties_annotation] if args.key?(:image_properties_annotation) @label_annotations = args[:label_annotations] if args.key?(:label_annotations) @landmark_annotations = args[:landmark_annotations] if args.key?(:landmark_annotations) @localized_object_annotations = args[:localized_object_annotations] if args.key?(:localized_object_annotations) @logo_annotations = args[:logo_annotations] if args.key?(:logo_annotations) @product_search_results = args[:product_search_results] if args.key?(:product_search_results) @safe_search_annotation = args[:safe_search_annotation] if args.key?(:safe_search_annotation) @text_annotations = args[:text_annotations] if args.key?(:text_annotations) @web_detection = args[:web_detection] if args.key?(:web_detection) end |