Class: Google::Apis::VisionV1p2beta1::SafeSearchAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1p2beta1::SafeSearchAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1p2beta1/classes.rb,
lib/google/apis/vision_v1p2beta1/representations.rb,
lib/google/apis/vision_v1p2beta1/representations.rb
Overview
Set of features pertaining to the image, computed by computer vision methods over safe-search verticals (for example, adult, spoof, medical, violence).
Instance Attribute Summary collapse
-
#adult ⇒ String
Represents the adult content likelihood for the image.
-
#medical ⇒ String
Likelihood that this is a medical image.
-
#racy ⇒ String
Likelihood that the request image contains racy content.
-
#spoof ⇒ String
Spoof likelihood.
-
#violence ⇒ String
Likelihood that this image contains violent content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SafeSearchAnnotation
constructor
A new instance of SafeSearchAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SafeSearchAnnotation
Returns a new instance of SafeSearchAnnotation.
9556 9557 9558 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9556 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adult ⇒ String
Represents the adult content likelihood for the image. Adult content may
contain elements such as nudity, pornographic images or cartoons, or sexual
activities.
Corresponds to the JSON property adult
9529 9530 9531 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9529 def adult @adult end |
#medical ⇒ String
Likelihood that this is a medical image.
Corresponds to the JSON property medical
9534 9535 9536 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9534 def medical @medical end |
#racy ⇒ String
Likelihood that the request image contains racy content. Racy content may
include (but is not limited to) skimpy or sheer clothing, strategically
covered nudity, lewd or provocative poses, or close-ups of sensitive body
areas.
Corresponds to the JSON property racy
9542 9543 9544 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9542 def racy @racy end |
#spoof ⇒ String
Spoof likelihood. The likelihood that an modification was made to the image's
canonical version to make it appear funny or offensive.
Corresponds to the JSON property spoof
9548 9549 9550 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9548 def spoof @spoof end |
#violence ⇒ String
Likelihood that this image contains violent content. Violent content may
include death, serious harm, or injury to individuals or groups of individuals.
Corresponds to the JSON property violence
9554 9555 9556 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9554 def violence @violence end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9561 9562 9563 9564 9565 9566 9567 |
# File 'lib/google/apis/vision_v1p2beta1/classes.rb', line 9561 def update!(**args) @adult = args[:adult] if args.key?(:adult) @medical = args[:medical] if args.key?(:medical) @racy = args[:racy] if args.key?(:racy) @spoof = args[:spoof] if args.key?(:spoof) @violence = args[:violence] if args.key?(:violence) end |